+++
title = "Multiple series"
series = ["Series A", "Series B"]
tags = ["front-matter", "series", "multiple"]
draft = false
+++

If a series name has spaces in it, wrap the whole name in double
quotes.
